@@ -859,22 +859,26 @@ class BaseExperiment:
         else:
             pseudomodel = model_type(**hparams)
         model_metadata = self.set_model_metadata(pseudomodel, hparams)
+        del_ckpt_path = f'{self.log_path}/checkpoints/{model_type.__name__}' 
+        del_json_path = f'{self.log_path}/jsonlogs/{model_type.__name__}'
+        del_tensorboard_path = f'{self.log_path}/tensorboardlogs/{model_type.__name__}' 
         ckpt_dir = f'{self.log_path}/checkpoints/{model_type.__name__}/{model_metadata}' 
         jsonlog_dir = f'{self.log_path}/jsonlogs/{model_type.__name__}/{model_metadata}' 
         tensorboard_dir =  f'{self.log_path}/tensorboardlogs/{model_type.__name__}/{model_metadata}' 
         if not os.path.exists(ckpt_dir) or not os.path.exists(jsonlog_dir) or not os.path.exists(tensorboard_dir):
+            logger.info(f"There is no such model that is saved.")
             return None
         
 
         success = {ckpt_dir:0, jsonlog_dir:0, tensorboard_dir:0}
         if os.path.exists(ckpt_dir):
-            shutil.rmtree(ckpt_dir)
+            shutil.rmtree(del_ckpt_path)
             success.update({ckpt_dir:1})
         if os.path.exists(jsonlog_dir):
-            shutil.rmtree(jsonlog_dir)
+            shutil.rmtree(del_json_path)
             success.update({jsonlog_dir:1})
         if os.path.exists(tensorboard_dir):
-            shutil.rmtree(tensorboard_dir)
+            shutil.rmtree(del_tensorboard_path)
             success.update({tensorboard_dir:1})
 
         for key, value in success.items():
